flutter_app_lock_pro library

Classes

AppLock
Pro app lock: route protection, auto-lock, PIN/biometric, wrong-attempt protection, secure screen, background blur.
AppLockConfig
Configuration for AppLock.
AppLockScope
Wraps your app and shows the lock overlay when AppLock is locked and user navigates to a protected route or returns from background.

Enums

UnlockMethod
Unlock method: PIN, pattern, or biometric (fingerprint / Face ID).