app_lock library
Classes
- AppLock
- Pro app lock: route protection, auto-lock, PIN/biometric, wrong-attempt protection, secure screen, background blur.
- AppLockScope
- Wraps your app and shows the lock overlay when AppLock is locked and user navigates to a protected route or returns from background.